package commands

import (
	"git.dragon-labs.de/alphyron/group_helper/cli"
	"git.dragon-labs.de/alphyron/group_helper/logic"
	tgbotapi "github.com/go-telegram-bot-api/telegram-bot-api"
	"strconv"
)

type toggleWritingForbidCommand struct {
	groupHelperService logic.GroupHelperService
}

func NewToggleWritingForbidCommand(groupHelperService logic.GroupHelperService) cli.Command {
	return &toggleWritingForbidCommand{
		groupHelperService: groupHelperService,
	}
}

func (i toggleWritingForbidCommand) GetUsage() string {
	return "/toggleWritingForbidCommand"
}

func (i toggleWritingForbidCommand) GetCommand() string {
	return "/toggleWritingForbidCommand"
}

func (i toggleWritingForbidCommand) GetDescription() string {
	return "Toggle the setting for forbid writing while not verified"
}

func (i toggleWritingForbidCommand) ExecuteCommand(bot *tgbotapi.BotAPI, update *tgbotapi.Update) (bool, error) {
	group, err := i.groupHelperService.GetGroupByID(update.Message.Chat.ID)

	if err != nil {
		return false, err
	}

	group.ForbidWriting = !group.ForbidWriting
	group, err = i.groupHelperService.UpdateGroup(group)

	if err != nil {
		return false, err
	}

	msg := tgbotapi.NewMessage(update.Message.Chat.ID, "Update the group setting for OnlineCheck to: "+strconv.FormatBool(group.OnlineCheck))
	_, err = bot.Send(msg)

	return err == nil, err
}

func (i toggleWritingForbidCommand) AllowChatType(chat *tgbotapi.Chat) bool {
	return chat.IsGroup() || chat.IsSuperGroup()
}

func (i toggleWritingForbidCommand) AllowMember(member *tgbotapi.ChatMember) bool {
	return member.IsAdministrator() || member.IsCreator()
}

func (i toggleWritingForbidCommand) AllowEveryMember() bool {
	return false
}
